# Cleans up results data for the 2008 election
# Removes unnecessary columns, formats numbers, and sorts by state.

# Output schema:
# state_abbrev,dem_percent,rep_percent

# Usage:
# python clean-2008-results.py [input path] [state abbrev. path]
# input path should contain raw election data
# state abbrev. path should map from state abbreviations to full names

# Cleaned data is sent to stdout

import sys
import locale
from functools import cmp_to_key

# Reads state abbreviations from the given path
# Returns a dictionary mapping full name to abbreviation
def get_state_abbrevs(path):
    result = {}
    for line in open(path, "r"):
        parts = line.split(",")
        result[parts[1]] = parts[0]
    return result

# Reads 2008 election data from data_path, and cleans it.
# abbrev_path is path to state abbreviation file
# Data is returned as a list of tuples in arbitrary order
def clean_2008_results(data_path, abbrev_path):
    abbrevs = get_state_abbrevs(abbrev_path)
    result = []
    first_line = True
    for line in open(data_path, "r"):
        if first_line == True:
            first_line = False
            continue
        parts = line.split("\t")
        state = abbrevs[parts[0]]
        dem_percent = parts[3].replace("%", "")
        rep_percent = parts[6].replace("%", "")
        result.append((state, dem_percent, rep_percent))
    return result

# Main Function
if __name__ == "__main__":
    data_path = sys.argv[1]
    abbrev_path = sys.argv[2]

    data = clean_2008_results(data_path, abbrev_path)
    data.sort(key=cmp_to_key(lambda t1, t2: locale.strcoll(t1[0], t2[0])))
    for line in data:
        print ",".join(line)
