# Cleans up census data from 2010
# Formats numbers and sorts by state

# Output schema:
# state_abbrev,population

# Usage:
# python clean-2010-census.py [input path] [state abbrev. path]
# input path should contain raw census data
# state abbrev. path should map from state abbreviations to full names

# Cleaned data is sent to stdout

import sys
import csv
import locale
import datetime as dt
from functools import cmp_to_key

DATE_FORMAT = "%b %d"

# Reads state abbreviations from the given path
# Returns a dictionary mapping full name to abbreviation
def get_state_abbrevs(path):
    result = {}
    for line in open(path, "r"):
        parts = line.split(",")
        result[parts[1]] = parts[0]
    return result

# Reads 2012 poll data from data_path, and cleans it.
# abbrev_path is path to state abbreviation file
# Data is returned as a list of tuples in arbitrary order
def clean_2010_census(data_path, abbrev_path):
    abbrevs = get_state_abbrevs(abbrev_path)

    # Special-case DC
    abbrevs["District of Columbia"] = "DC"

    reader = csv.reader(open(data_path))
    reader.next()

    result = []

    for line in reader:
        state = abbrevs[line[0].strip()]
        pop_str = line[1]
        pop_clean = pop_str.replace(",", "")
        pop = int(pop_clean)*1000
        result.append((state, str(pop)))

    return result

# Main Function
if __name__ == "__main__":
    data_path = sys.argv[1]
    abbrev_path = sys.argv[2]

    data = clean_2010_census(data_path, abbrev_path)
    data.sort(key=cmp_to_key(lambda t1, t2: locale.strcoll(t1[0], t2[0])))
    for line in data:
        print ",".join(line)
